<?php
/**
 * Plugin Name:Cryptocurrency Donation Box - Bitcoin & Crypto Donations
 * Description:Create cryptocurrency donation box and accept crypto coin payments, show coin address and QR code - best bitcoin & crypto donations plugin.
 * Plugin URI:https://coolplugins.net/
 * Author:Cool Plugins
 * Author URI:https://coolplugins.net/
 * Version: 2.0
 * License: GPL2
 * Text Domain:CDBBC
 * Domain Path: /languages
 *
 * @package Cryptocurrency_Donation_Box
 */

/*
Copyright (C) 2018  CoolPlugins contact@coolplugins.net

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License, version 2, as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

if (!defined('ABSPATH')) {
    exit;
}

if (defined('CDBBC_VERSION')) {
    return;
}

define('CDBBC_VERSION', '2.0');
define('CDBBC_FILE', __FILE__);
define('CDBBC_PATH', plugin_dir_path(CDBBC_FILE));
define('CDBBC_URL', plugin_dir_url(CDBBC_FILE));

register_activation_hook(CDBBC_FILE, array('Cryptocurrency_Donation_Box', 'activate'));
register_deactivation_hook(CDBBC_FILE, array('Cryptocurrency_Donation_Box', 'deactivate'));

/**
 * Class Cryptocurrency_Donation_Box
 */
final class Cryptocurrency_Donation_Box
{

    /**
     * Plugin instance.
     *
     * @var Cryptocurrency_Donation_Box
     * @access private
     */
    private static $instance = null;

    /**
     * Get plugin instance.
     *
     * @return Cryptocurrency_Donation_Box
     * @static
     */
    public static function get_instance()
    {

        if (!isset(self::$instance)) {
            self::$instance = new self();
        }

        return self::$instance;
    }

    /**
     * Constructor.
     *
     * @access private
     */
    private function __construct()
    {
        $this->cdbbc_includes();
        add_action('admin_init', array($this, 'CDBBC_do_activation_redirect'));
        //add_shortcode( 'crypto-donation-box', array( $this, 'crypto_donation_box_shortcode' ) );
        add_action('plugins_loaded', array($this, 'cdbbc_load_lang'));
        add_action('init', array($this, 'cdbbc_plugin_version_verify'));
        if (is_admin()) {

            require_once CDBBC_PATH . 'admin/addon-dashboard-page/addon-dashboard-page.php';
            cool_plugins_crypto_addon_settings_page('crypto', 'cool-crypto-plugins', 'Cryptocurrency plugins by CoolPlugins.net', 'Crypto Plugins', 'dashicons-chart-area');

            add_filter('plugin_action_links_' . plugin_basename(__FILE__), array($this, 'cdbbc_setting_panel_action_link'));
            require_once CDBBC_PATH . '/admin/feedback/admin-feedback-form.php';
            require_once CDBBC_PATH . '/admin/class.review-notice.php';
            add_action('admin_menu', array($this, 'CDBBC_create_submenus'));

            // notice for review
            add_action('admin_enqueue_scripts', array($this, 'cdbbc_admin_scripts'));

        }
    }

    public function CDBBC_create_submenus()
    {

        add_submenu_page('cool-crypto-plugins', ' Crpto Donation Box', '<strong>Crpto Donation Box</strong>', 'manage_options', 'admin.php?page=cdbbc-add-wallet', false, 10);
         add_submenu_page('cool-crypto-plugins', ' ↳ Add Wallet/Coin', '↳ Add Wallet/Coin', 'manage_options', 'admin.php?page=cdbbc-add-wallet', false, 10);
         add_submenu_page('cool-crypto-plugins', ' Settings', '↳ Settings', 'manage_options', 'admin.php?page=cdbbc-coin-settings', false, 10);


    }

    /*
    |--------------------------------------------------------------------------
    |  admin style
    |--------------------------------------------------------------------------
     */
    public function cdbbc_admin_scripts()
    {

        wp_enqueue_style('cdbbc-custom-admin-style', CDBBC_URL . 'assets/css/cdbbc-admin.css', null, CDBBC_VERSION);
        wp_enqueue_script('cdbbc-custom-admin-scripts', CDBBC_URL . 'assets/js/cdbbc-admin.js',  array('jquery'), CDBBC_VERSION);

    }
    /**
     * Load plugin function
     */
    public function cdbbc_includes()
    {
        $post_array = array('cdbbc-add-wallet', 'cdbbc-coin-settings');
        if (isset($_POST['submit-cmb']) || in_array($this->cdbbc_get_post_type_page(), $post_array)) {
            require_once CDBBC_PATH . 'admin/cmb2/init.php';
            require_once CDBBC_PATH . 'admin/cmb2/cmb2-conditionals.php';

        }
        require_once CDBBC_PATH . 'admin/cdbbc-settings.php';

        require_once CDBBC_PATH . '/includes/cdbbc-shortcode.php';

        require_once dirname(__FILE__) . '/includes/functions.php';

    }

    /*
    |--------------------------------------------------------------------------
    |  check admin side post type page
    |--------------------------------------------------------------------------
     */
    public function cdbbc_get_post_type_page()
    {
        global $post, $typenow, $current_screen;

        if ($post && $post->post_type) {
            return $post->post_type;
        } elseif ($typenow) {
            return $typenow;
        } elseif ($current_screen && $current_screen->post_type) {
            return $current_screen->post_type;
        } elseif (isset($_REQUEST['page'])) {
            return sanitize_key($_REQUEST['page']);
        } elseif (isset($_REQUEST['post_type'])) {
            return sanitize_key($_REQUEST['post_type']);
        } elseif (isset($_REQUEST['post'])) {
            return get_post_type(sanitize_text_field($_REQUEST['post']));
        }
        return null;
    }

    /**
     * Code you want to run when all other plugins loaded.
     */
    public function cdbbc_load_lang()
    {
        load_plugin_textdomain('CDBBC', false, dirname(plugin_basename(__FILE__)) . '/languages/');
    }
    /**
     * Run when activate plugin.
     */
    public static function activate()
    {
        add_option('CDBBC_do_activation_redirect', true);
        update_option('cdbbc_activation_time', gmdate('Y-m-d h:i:s'));
        update_option('cdbbc-alreadyRated', 'no');       
        update_option('CDBBC_FRESH_INSTALLATION', CDBBC_VERSION);
        
    }

    public function CDBBC_do_activation_redirect()
    {
        if (get_option('CDBBC_do_activation_redirect', false)) {
            delete_option('CDBBC_do_activation_redirect');
            if (!isset($_GET['activate-multi'])) {
                wp_redirect(admin_url('admin.php?page=cdbbc-add-wallet'));
            }
        }
    }
    /*
    |--------------------------------------------------------------------------
    |  Check if plugin is just updated from older version to new
    |--------------------------------------------------------------------------
     */
    public function cdbbc_plugin_version_verify()
    {

        $CDBBC_VERSION = get_option('CDBBC_FREE_VERSION');
        if (!isset($CDBBC_VERSION) || version_compare($CDBBC_VERSION, CDBBC_VERSION, '<')) {

            if (empty(get_option('cdbbc_migarte_settings')) && empty(get_option('CDBBC_FRESH_INSTALLATION'))) {
                cdbbc_migrate_data();
                update_option('cdbbc_migarte_settings', 'migrated');
            }

            update_option('CDBBC_FREE_VERSION', CDBBC_VERSION);

        }

    }

    /**
     * Run when deactivate plugin.
     */
    public static function deactivate()
    {}

    public function cdbbc_setting_panel_action_link($link)
    {
        $link[] = '<a style="font-weight:bold" href="' . esc_url(get_admin_url(null, 'admin.php?page=cdbbc-add-wallet')) . '">Settings</a>';
        return $link;
    }
}

function Cryptocurrency_Donation_Box()
{
    return Cryptocurrency_Donation_Box::get_instance();
}

$GLOBALS['Cryptocurrency_Donation_Box'] = Cryptocurrency_Donation_Box();
