<?php
if (!defined('ABSPATH')) {
    exit();
}

/**
 * Get the value of a settings field
 *
 * @param string $option settings field name
 * @param string $section the section name this field belongs to
 * @param string $default default text if it's not found
 *
 * @return mixed
 */
function CDBBC_get_option($option, $section, $default = '')
{
    $options = get_option($section);

    if (isset($options[$option])) {
        return $options[$option];
    }

    return $default;
}

// fetch settings array
function CDBBC_get_option_arr($section, $default = '')
{
    $options = get_option($section);
    if (isset($options) && is_array($options)) {
        return $options;
    }

    return $default;
}

// supported donation coin array
function CDBBC_supported_coins()
{
    return $coins = array(
        'bitcoin' => 'Bitcoin(BTC)',
        'ethereum' => 'Ethereum(ETH)',
        'metamask' => 'MetaMask(ETH)',
        'tether' => 'Tether(USDT)',
        'cardano' => 'Cardano(ADA)',
        'xrp' => 'XRP ',
        'polkadot' => 'Polkadot(DOT)',
        'binance-coin' => 'Binance Coin(BNB)',
        'litecoin' => 'Litecoin(LTC)',
        'chainlink' => 'Chainlink(LINK)',
        'stellar' => 'Stellar(XLM)',
        'bitcoin-cash' => 'Bitcoin Cash(BCH)',
        'dogecoin' => 'Dogecoin(DOGE)',
        'usdcoin' => 'USD COIN(USDC)',
        'aave' => 'Aave(AAVE)',
        'uniswap' => 'Uniswap(UNI)',
        'wrappedbitcoin' => 'Wrapped Bitcoin(WBTC)',
        'avalanche' => 'Avalanche(AVAX)',
        'bitcoin-sv' => 'Bitcoin SV(BSV)',
        'eos' => 'EOS',
        'nem' => 'NEM(XEM)',
        'tron' => 'Tron(TRX)',
        'cosmos' => 'Cosmos(ATOM)',
        'monero' => 'Monero(XMR)',
        'tezos' => 'Tezos(XTZ)',
        'elrond' => 'Elrond(EGLD)',
        'iota' => 'IOTA(MIOTA)',
        'theta' => 'THETA(THETA)',
        'synthetix' => 'Synthetix(SNX)',
        'dash' => 'Dash',
        'maker' => 'Maker(MKR)',
        'dai' => 'Dai(DAI)',
        'ethereum-classic' => 'Ethereum Classic(ETC)',
        'lisk' => 'Lisk',
        'neo' => 'NEO',
        'vechain' => 'VeChain(VET)',
        'qtum' => 'Qtum',
        'omisego' => 'OmiseGO',
        'icon' => 'ICON(ICX)',
        'nano' => 'Nano',
        'verge' => 'Verge',
        'bytecoin-bcn' => 'Bytecoin',
        'zcash' => 'Zcash(ZEC)',
        'ontology' => 'Ontology(ONT)',
        'aeternity' => 'Aeternity',
        'steem' => 'Steem',
        'digibyte'=>'Digibyte',
        'polygon-matic'=>'Polygon (MATIC)'

    );
}

function cdbbc_get_gen_option($key = '', $default = false)
{
/* $chk_old_option=cmc_get_titan_settings($key);
if(!empty($chk_old_option)){
return $chk_old_option;
}
 */
    if (function_exists('cmb2_get_option')) {
        // Use cmb2_get_option as it passes through some key filters.
        return cmb2_get_option('cdbbc-add-wallet', $key, $default);
    }

    // Fallback to get_option if CMB2 is not loaded yet.
    $opts = get_option('cdbbc-add-wallet', $default);

    $val = $default;

    if ('all' == $key) {
        $val = $opts;
    } elseif (is_array($opts) && array_key_exists($key, $opts) && false !== $opts[$key]) {
        $val = $opts[$key];
    }

    return $val;
}

function cdbbc_get_extra_option($key = '', $default = false)
{
    if (function_exists('cmb2_get_option')) {
        // Use cmb2_get_option as it passes through some key filters.
        return cmb2_get_option('cdbbc-coin-settings', $key, $default);
    }

    // Fallback to get_option if CMB2 is not loaded yet.
    $opts = get_option('cdbbc-coin-settings', $default);

    $val = $default;

    if ('all' == $key) {
        $val = $opts;
    } elseif (is_array($opts) && array_key_exists($key, $opts) && false !== $opts[$key]) {
        $val = $opts[$key];
    }

    return $val;
}

function cdbbc_migrate_data()
{
    $all_coin_wall1 = CDBBC_get_option_arr('wallet_addresses');
    $all_coin_wall2 = CDBBC_get_option_arr('wallet_addresses1');
    $all_coin_list1 = !empty($all_coin_wall1) ? $all_coin_wall1 : array();
    $all_coin_list2 = !empty($all_coin_wall2) ? $all_coin_wall2 : array();
    $all_coin_wall_add343 = array_merge($all_coin_list1, $all_coin_list2);
    $new_gen_settigs = get_option('cdbbc-add-wallet');
    $new_extra_settigs = get_option('cdbbc-coin-settings');
    $old_wallet = array_filter($all_coin_wall_add343);

    $migrate_data = [];
    if (is_array($old_wallet) && !empty($old_wallet)) {
        foreach ($old_wallet as $key => $values) {

            if (strpos($key, 'tag') !== false) {
                continue;
            }
            $migrate_data['cdbbc_group_data'][] = array(
                "coin_type" => "popular",
                "coin" => $key,
                'wallet_address' => $old_wallet[$key],
                'tag_note' => !empty($old_wallet[$key . '_tag']) ? $old_wallet[$key . '_tag'] : "",
            );
        }
    }

    $extra_settings = array(
        'metamask_title' => !empty(CDBBC_get_option('maintitle-metamask', 'coolplugins_advanced')) ? CDBBC_get_option('maintitle-metamask', 'coolplugins_advanced') : 'Donate With MetaMask',
        'metamask_desc' => !empty(CDBBC_get_option('cdb-metamask-desc', 'coolplugins_advanced')) ? CDBBC_get_option('cdb-metamask-desc', 'coolplugins_advanced') : 'Donate ETH Via PAY With Metamask',
        'main_title' => !empty(CDBBC_get_option('main-title', 'coolplugins_advanced')) ? CDBBC_get_option('main-title', 'coolplugins_advanced') : 'Donate [coin-name] to this address',
        'main_desc' => !empty(CDBBC_get_option('cdb-desc', 'coolplugins_advanced')) ? CDBBC_get_option('cdb-desc', 'coolplugins_advanced') : 'Scan the QR code or copy the address below into your wallet to send some [coin-name]',
        'metamask_amount' => '0.005',
    );
    update_option('cdbbc-add-wallet', $migrate_data);
    update_option('cdbbc-coin-settings', $extra_settings);

}
